@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """
 requests.certs
@@ -15,5 +14,5 @@ packaged CA bundle.
 def where():
     return "/etc/ssl/certs/ca-certificates.crt"
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(where())
